#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MINMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MINMAG_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/minmag.hpp>

#endif
